# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: flyteidl/plugins/sagemaker/training_job.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='flyteidl/plugins/sagemaker/training_job.proto',
  package='flyteidl.plugins.sagemaker',
  syntax='proto3',
  serialized_options=_b('Z3github.com/lyft/flyteidl/gen/pb-go/flyteidl/plugins'),
  serialized_pb=_b('\n-flyteidl/plugins/sagemaker/training_job.proto\x12\x1a\x66lyteidl.plugins.sagemaker\x1a\x1egoogle/protobuf/duration.proto\"(\n\tInputMode\"\x1b\n\x05Value\x12\x08\n\x04\x46ILE\x10\x00\x12\x08\n\x04PIPE\x10\x01\"1\n\rAlgorithmName\" \n\x05Value\x12\n\n\x06\x43USTOM\x10\x00\x12\x0b\n\x07XGBOOST\x10\x01\")\n\x10InputContentType\"\x15\n\x05Value\x12\x0c\n\x08TEXT_CSV\x10\x00\"/\n\x10MetricDefinition\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05regex\x18\x02 \x01(\t\"\xd7\x02\n\x16\x41lgorithmSpecification\x12?\n\ninput_mode\x18\x01 \x01(\x0e\x32+.flyteidl.plugins.sagemaker.InputMode.Value\x12G\n\x0e\x61lgorithm_name\x18\x02 \x01(\x0e\x32/.flyteidl.plugins.sagemaker.AlgorithmName.Value\x12\x19\n\x11\x61lgorithm_version\x18\x03 \x01(\t\x12H\n\x12metric_definitions\x18\x04 \x03(\x0b\x32,.flyteidl.plugins.sagemaker.MetricDefinition\x12N\n\x12input_content_type\x18\x05 \x01(\x0e\x32\x32.flyteidl.plugins.sagemaker.InputContentType.Value\"e\n\x19TrainingJobResourceConfig\x12\x16\n\x0einstance_count\x18\x01 \x01(\x03\x12\x15\n\rinstance_type\x18\x02 \x01(\t\x12\x19\n\x11volume_size_in_gb\x18\x03 \x01(\x03\"\xbf\x01\n\x0bTrainingJob\x12S\n\x17\x61lgorithm_specification\x18\x01 \x01(\x0b\x32\x32.flyteidl.plugins.sagemaker.AlgorithmSpecification\x12[\n\x1ctraining_job_resource_config\x18\x02 \x01(\x0b\x32\x35.flyteidl.plugins.sagemaker.TrainingJobResourceConfigB5Z3github.com/lyft/flyteidl/gen/pb-go/flyteidl/pluginsb\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,])



_INPUTMODE_VALUE = _descriptor.EnumDescriptor(
  name='Value',
  full_name='flyteidl.plugins.sagemaker.InputMode.Value',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='FILE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PIPE', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=122,
  serialized_end=149,
)
_sym_db.RegisterEnumDescriptor(_INPUTMODE_VALUE)

_ALGORITHMNAME_VALUE = _descriptor.EnumDescriptor(
  name='Value',
  full_name='flyteidl.plugins.sagemaker.AlgorithmName.Value',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CUSTOM', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='XGBOOST', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=168,
  serialized_end=200,
)
_sym_db.RegisterEnumDescriptor(_ALGORITHMNAME_VALUE)

_INPUTCONTENTTYPE_VALUE = _descriptor.EnumDescriptor(
  name='Value',
  full_name='flyteidl.plugins.sagemaker.InputContentType.Value',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TEXT_CSV', index=0, number=0,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=222,
  serialized_end=243,
)
_sym_db.RegisterEnumDescriptor(_INPUTCONTENTTYPE_VALUE)


_INPUTMODE = _descriptor.Descriptor(
  name='InputMode',
  full_name='flyteidl.plugins.sagemaker.InputMode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _INPUTMODE_VALUE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=109,
  serialized_end=149,
)


_ALGORITHMNAME = _descriptor.Descriptor(
  name='AlgorithmName',
  full_name='flyteidl.plugins.sagemaker.AlgorithmName',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ALGORITHMNAME_VALUE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=151,
  serialized_end=200,
)


_INPUTCONTENTTYPE = _descriptor.Descriptor(
  name='InputContentType',
  full_name='flyteidl.plugins.sagemaker.InputContentType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _INPUTCONTENTTYPE_VALUE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=202,
  serialized_end=243,
)


_METRICDEFINITION = _descriptor.Descriptor(
  name='MetricDefinition',
  full_name='flyteidl.plugins.sagemaker.MetricDefinition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='flyteidl.plugins.sagemaker.MetricDefinition.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='regex', full_name='flyteidl.plugins.sagemaker.MetricDefinition.regex', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=245,
  serialized_end=292,
)


_ALGORITHMSPECIFICATION = _descriptor.Descriptor(
  name='AlgorithmSpecification',
  full_name='flyteidl.plugins.sagemaker.AlgorithmSpecification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='input_mode', full_name='flyteidl.plugins.sagemaker.AlgorithmSpecification.input_mode', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='algorithm_name', full_name='flyteidl.plugins.sagemaker.AlgorithmSpecification.algorithm_name', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='algorithm_version', full_name='flyteidl.plugins.sagemaker.AlgorithmSpecification.algorithm_version', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metric_definitions', full_name='flyteidl.plugins.sagemaker.AlgorithmSpecification.metric_definitions', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='input_content_type', full_name='flyteidl.plugins.sagemaker.AlgorithmSpecification.input_content_type', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=295,
  serialized_end=638,
)


_TRAININGJOBRESOURCECONFIG = _descriptor.Descriptor(
  name='TrainingJobResourceConfig',
  full_name='flyteidl.plugins.sagemaker.TrainingJobResourceConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance_count', full_name='flyteidl.plugins.sagemaker.TrainingJobResourceConfig.instance_count', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instance_type', full_name='flyteidl.plugins.sagemaker.TrainingJobResourceConfig.instance_type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='volume_size_in_gb', full_name='flyteidl.plugins.sagemaker.TrainingJobResourceConfig.volume_size_in_gb', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=640,
  serialized_end=741,
)


_TRAININGJOB = _descriptor.Descriptor(
  name='TrainingJob',
  full_name='flyteidl.plugins.sagemaker.TrainingJob',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='algorithm_specification', full_name='flyteidl.plugins.sagemaker.TrainingJob.algorithm_specification', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='training_job_resource_config', full_name='flyteidl.plugins.sagemaker.TrainingJob.training_job_resource_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=744,
  serialized_end=935,
)

_INPUTMODE_VALUE.containing_type = _INPUTMODE
_ALGORITHMNAME_VALUE.containing_type = _ALGORITHMNAME
_INPUTCONTENTTYPE_VALUE.containing_type = _INPUTCONTENTTYPE
_ALGORITHMSPECIFICATION.fields_by_name['input_mode'].enum_type = _INPUTMODE_VALUE
_ALGORITHMSPECIFICATION.fields_by_name['algorithm_name'].enum_type = _ALGORITHMNAME_VALUE
_ALGORITHMSPECIFICATION.fields_by_name['metric_definitions'].message_type = _METRICDEFINITION
_ALGORITHMSPECIFICATION.fields_by_name['input_content_type'].enum_type = _INPUTCONTENTTYPE_VALUE
_TRAININGJOB.fields_by_name['algorithm_specification'].message_type = _ALGORITHMSPECIFICATION
_TRAININGJOB.fields_by_name['training_job_resource_config'].message_type = _TRAININGJOBRESOURCECONFIG
DESCRIPTOR.message_types_by_name['InputMode'] = _INPUTMODE
DESCRIPTOR.message_types_by_name['AlgorithmName'] = _ALGORITHMNAME
DESCRIPTOR.message_types_by_name['InputContentType'] = _INPUTCONTENTTYPE
DESCRIPTOR.message_types_by_name['MetricDefinition'] = _METRICDEFINITION
DESCRIPTOR.message_types_by_name['AlgorithmSpecification'] = _ALGORITHMSPECIFICATION
DESCRIPTOR.message_types_by_name['TrainingJobResourceConfig'] = _TRAININGJOBRESOURCECONFIG
DESCRIPTOR.message_types_by_name['TrainingJob'] = _TRAININGJOB
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

InputMode = _reflection.GeneratedProtocolMessageType('InputMode', (_message.Message,), dict(
  DESCRIPTOR = _INPUTMODE,
  __module__ = 'flyteidl.plugins.sagemaker.training_job_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.plugins.sagemaker.InputMode)
  ))
_sym_db.RegisterMessage(InputMode)

AlgorithmName = _reflection.GeneratedProtocolMessageType('AlgorithmName', (_message.Message,), dict(
  DESCRIPTOR = _ALGORITHMNAME,
  __module__ = 'flyteidl.plugins.sagemaker.training_job_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.plugins.sagemaker.AlgorithmName)
  ))
_sym_db.RegisterMessage(AlgorithmName)

InputContentType = _reflection.GeneratedProtocolMessageType('InputContentType', (_message.Message,), dict(
  DESCRIPTOR = _INPUTCONTENTTYPE,
  __module__ = 'flyteidl.plugins.sagemaker.training_job_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.plugins.sagemaker.InputContentType)
  ))
_sym_db.RegisterMessage(InputContentType)

MetricDefinition = _reflection.GeneratedProtocolMessageType('MetricDefinition', (_message.Message,), dict(
  DESCRIPTOR = _METRICDEFINITION,
  __module__ = 'flyteidl.plugins.sagemaker.training_job_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.plugins.sagemaker.MetricDefinition)
  ))
_sym_db.RegisterMessage(MetricDefinition)

AlgorithmSpecification = _reflection.GeneratedProtocolMessageType('AlgorithmSpecification', (_message.Message,), dict(
  DESCRIPTOR = _ALGORITHMSPECIFICATION,
  __module__ = 'flyteidl.plugins.sagemaker.training_job_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.plugins.sagemaker.AlgorithmSpecification)
  ))
_sym_db.RegisterMessage(AlgorithmSpecification)

TrainingJobResourceConfig = _reflection.GeneratedProtocolMessageType('TrainingJobResourceConfig', (_message.Message,), dict(
  DESCRIPTOR = _TRAININGJOBRESOURCECONFIG,
  __module__ = 'flyteidl.plugins.sagemaker.training_job_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.plugins.sagemaker.TrainingJobResourceConfig)
  ))
_sym_db.RegisterMessage(TrainingJobResourceConfig)

TrainingJob = _reflection.GeneratedProtocolMessageType('TrainingJob', (_message.Message,), dict(
  DESCRIPTOR = _TRAININGJOB,
  __module__ = 'flyteidl.plugins.sagemaker.training_job_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.plugins.sagemaker.TrainingJob)
  ))
_sym_db.RegisterMessage(TrainingJob)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: flyteidl/plugins/sagemaker/hyperparameter_tuning_job.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from flyteidl.plugins.sagemaker import parameter_ranges_pb2 as flyteidl_dot_plugins_dot_sagemaker_dot_parameter__ranges__pb2
from flyteidl.plugins.sagemaker import training_job_pb2 as flyteidl_dot_plugins_dot_sagemaker_dot_training__job__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='flyteidl/plugins/sagemaker/hyperparameter_tuning_job.proto',
  package='flyteidl.plugins.sagemaker',
  syntax='proto3',
  serialized_options=_b('Z3github.com/lyft/flyteidl/gen/pb-go/flyteidl/plugins'),
  serialized_pb=_b('\n:flyteidl/plugins/sagemaker/hyperparameter_tuning_job.proto\x12\x1a\x66lyteidl.plugins.sagemaker\x1a\x31\x66lyteidl/plugins/sagemaker/parameter_ranges.proto\x1a-flyteidl/plugins/sagemaker/training_job.proto\"\xa1\x01\n\x17HyperparameterTuningJob\x12=\n\x0ctraining_job\x18\x01 \x01(\x0b\x32\'.flyteidl.plugins.sagemaker.TrainingJob\x12#\n\x1bmax_number_of_training_jobs\x18\x02 \x01(\x03\x12\"\n\x1amax_parallel_training_jobs\x18\x03 \x01(\x03\"H\n!HyperparameterTuningObjectiveType\"#\n\x05Value\x12\x0c\n\x08MINIMIZE\x10\x00\x12\x0c\n\x08MAXIMIZE\x10\x01\"\x91\x01\n\x1dHyperparameterTuningObjective\x12[\n\x0eobjective_type\x18\x01 \x01(\x0e\x32\x43.flyteidl.plugins.sagemaker.HyperparameterTuningObjectiveType.Value\x12\x13\n\x0bmetric_name\x18\x02 \x01(\t\"A\n\x1cHyperparameterTuningStrategy\"!\n\x05Value\x12\x0c\n\x08\x42\x41YESIAN\x10\x00\x12\n\n\x06RANDOM\x10\x01\":\n\x1cTrainingJobEarlyStoppingType\"\x1a\n\x05Value\x12\x07\n\x03OFF\x10\x00\x12\x08\n\x04\x41UTO\x10\x01\"\x83\x03\n\x1dHyperparameterTuningJobConfig\x12J\n\x15hyperparameter_ranges\x18\x01 \x01(\x0b\x32+.flyteidl.plugins.sagemaker.ParameterRanges\x12W\n\x0ftuning_strategy\x18\x02 \x01(\x0e\x32>.flyteidl.plugins.sagemaker.HyperparameterTuningStrategy.Value\x12S\n\x10tuning_objective\x18\x03 \x01(\x0b\x32\x39.flyteidl.plugins.sagemaker.HyperparameterTuningObjective\x12h\n training_job_early_stopping_type\x18\x04 \x01(\x0e\x32>.flyteidl.plugins.sagemaker.TrainingJobEarlyStoppingType.ValueB5Z3github.com/lyft/flyteidl/gen/pb-go/flyteidl/pluginsb\x06proto3')
  ,
  dependencies=[flyteidl_dot_plugins_dot_sagemaker_dot_parameter__ranges__pb2.DESCRIPTOR,flyteidl_dot_plugins_dot_sagemaker_dot_training__job__pb2.DESCRIPTOR,])



_HYPERPARAMETERTUNINGOBJECTIVETYPE_VALUE = _descriptor.EnumDescriptor(
  name='Value',
  full_name='flyteidl.plugins.sagemaker.HyperparameterTuningObjectiveType.Value',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MINIMIZE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MAXIMIZE', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=389,
  serialized_end=424,
)
_sym_db.RegisterEnumDescriptor(_HYPERPARAMETERTUNINGOBJECTIVETYPE_VALUE)

_HYPERPARAMETERTUNINGSTRATEGY_VALUE = _descriptor.EnumDescriptor(
  name='Value',
  full_name='flyteidl.plugins.sagemaker.HyperparameterTuningStrategy.Value',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BAYESIAN', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RANDOM', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=606,
  serialized_end=639,
)
_sym_db.RegisterEnumDescriptor(_HYPERPARAMETERTUNINGSTRATEGY_VALUE)

_TRAININGJOBEARLYSTOPPINGTYPE_VALUE = _descriptor.EnumDescriptor(
  name='Value',
  full_name='flyteidl.plugins.sagemaker.TrainingJobEarlyStoppingType.Value',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OFF', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AUTO', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=673,
  serialized_end=699,
)
_sym_db.RegisterEnumDescriptor(_TRAININGJOBEARLYSTOPPINGTYPE_VALUE)


_HYPERPARAMETERTUNINGJOB = _descriptor.Descriptor(
  name='HyperparameterTuningJob',
  full_name='flyteidl.plugins.sagemaker.HyperparameterTuningJob',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='training_job', full_name='flyteidl.plugins.sagemaker.HyperparameterTuningJob.training_job', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_number_of_training_jobs', full_name='flyteidl.plugins.sagemaker.HyperparameterTuningJob.max_number_of_training_jobs', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_parallel_training_jobs', full_name='flyteidl.plugins.sagemaker.HyperparameterTuningJob.max_parallel_training_jobs', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=189,
  serialized_end=350,
)


_HYPERPARAMETERTUNINGOBJECTIVETYPE = _descriptor.Descriptor(
  name='HyperparameterTuningObjectiveType',
  full_name='flyteidl.plugins.sagemaker.HyperparameterTuningObjectiveType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _HYPERPARAMETERTUNINGOBJECTIVETYPE_VALUE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=352,
  serialized_end=424,
)


_HYPERPARAMETERTUNINGOBJECTIVE = _descriptor.Descriptor(
  name='HyperparameterTuningObjective',
  full_name='flyteidl.plugins.sagemaker.HyperparameterTuningObjective',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='objective_type', full_name='flyteidl.plugins.sagemaker.HyperparameterTuningObjective.objective_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metric_name', full_name='flyteidl.plugins.sagemaker.HyperparameterTuningObjective.metric_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=427,
  serialized_end=572,
)


_HYPERPARAMETERTUNINGSTRATEGY = _descriptor.Descriptor(
  name='HyperparameterTuningStrategy',
  full_name='flyteidl.plugins.sagemaker.HyperparameterTuningStrategy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _HYPERPARAMETERTUNINGSTRATEGY_VALUE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=574,
  serialized_end=639,
)


_TRAININGJOBEARLYSTOPPINGTYPE = _descriptor.Descriptor(
  name='TrainingJobEarlyStoppingType',
  full_name='flyteidl.plugins.sagemaker.TrainingJobEarlyStoppingType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TRAININGJOBEARLYSTOPPINGTYPE_VALUE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=641,
  serialized_end=699,
)


_HYPERPARAMETERTUNINGJOBCONFIG = _descriptor.Descriptor(
  name='HyperparameterTuningJobConfig',
  full_name='flyteidl.plugins.sagemaker.HyperparameterTuningJobConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hyperparameter_ranges', full_name='flyteidl.plugins.sagemaker.HyperparameterTuningJobConfig.hyperparameter_ranges', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tuning_strategy', full_name='flyteidl.plugins.sagemaker.HyperparameterTuningJobConfig.tuning_strategy', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tuning_objective', full_name='flyteidl.plugins.sagemaker.HyperparameterTuningJobConfig.tuning_objective', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='training_job_early_stopping_type', full_name='flyteidl.plugins.sagemaker.HyperparameterTuningJobConfig.training_job_early_stopping_type', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=702,
  serialized_end=1089,
)

_HYPERPARAMETERTUNINGJOB.fields_by_name['training_job'].message_type = flyteidl_dot_plugins_dot_sagemaker_dot_training__job__pb2._TRAININGJOB
_HYPERPARAMETERTUNINGOBJECTIVETYPE_VALUE.containing_type = _HYPERPARAMETERTUNINGOBJECTIVETYPE
_HYPERPARAMETERTUNINGOBJECTIVE.fields_by_name['objective_type'].enum_type = _HYPERPARAMETERTUNINGOBJECTIVETYPE_VALUE
_HYPERPARAMETERTUNINGSTRATEGY_VALUE.containing_type = _HYPERPARAMETERTUNINGSTRATEGY
_TRAININGJOBEARLYSTOPPINGTYPE_VALUE.containing_type = _TRAININGJOBEARLYSTOPPINGTYPE
_HYPERPARAMETERTUNINGJOBCONFIG.fields_by_name['hyperparameter_ranges'].message_type = flyteidl_dot_plugins_dot_sagemaker_dot_parameter__ranges__pb2._PARAMETERRANGES
_HYPERPARAMETERTUNINGJOBCONFIG.fields_by_name['tuning_strategy'].enum_type = _HYPERPARAMETERTUNINGSTRATEGY_VALUE
_HYPERPARAMETERTUNINGJOBCONFIG.fields_by_name['tuning_objective'].message_type = _HYPERPARAMETERTUNINGOBJECTIVE
_HYPERPARAMETERTUNINGJOBCONFIG.fields_by_name['training_job_early_stopping_type'].enum_type = _TRAININGJOBEARLYSTOPPINGTYPE_VALUE
DESCRIPTOR.message_types_by_name['HyperparameterTuningJob'] = _HYPERPARAMETERTUNINGJOB
DESCRIPTOR.message_types_by_name['HyperparameterTuningObjectiveType'] = _HYPERPARAMETERTUNINGOBJECTIVETYPE
DESCRIPTOR.message_types_by_name['HyperparameterTuningObjective'] = _HYPERPARAMETERTUNINGOBJECTIVE
DESCRIPTOR.message_types_by_name['HyperparameterTuningStrategy'] = _HYPERPARAMETERTUNINGSTRATEGY
DESCRIPTOR.message_types_by_name['TrainingJobEarlyStoppingType'] = _TRAININGJOBEARLYSTOPPINGTYPE
DESCRIPTOR.message_types_by_name['HyperparameterTuningJobConfig'] = _HYPERPARAMETERTUNINGJOBCONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

HyperparameterTuningJob = _reflection.GeneratedProtocolMessageType('HyperparameterTuningJob', (_message.Message,), dict(
  DESCRIPTOR = _HYPERPARAMETERTUNINGJOB,
  __module__ = 'flyteidl.plugins.sagemaker.hyperparameter_tuning_job_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.plugins.sagemaker.HyperparameterTuningJob)
  ))
_sym_db.RegisterMessage(HyperparameterTuningJob)

HyperparameterTuningObjectiveType = _reflection.GeneratedProtocolMessageType('HyperparameterTuningObjectiveType', (_message.Message,), dict(
  DESCRIPTOR = _HYPERPARAMETERTUNINGOBJECTIVETYPE,
  __module__ = 'flyteidl.plugins.sagemaker.hyperparameter_tuning_job_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.plugins.sagemaker.HyperparameterTuningObjectiveType)
  ))
_sym_db.RegisterMessage(HyperparameterTuningObjectiveType)

HyperparameterTuningObjective = _reflection.GeneratedProtocolMessageType('HyperparameterTuningObjective', (_message.Message,), dict(
  DESCRIPTOR = _HYPERPARAMETERTUNINGOBJECTIVE,
  __module__ = 'flyteidl.plugins.sagemaker.hyperparameter_tuning_job_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.plugins.sagemaker.HyperparameterTuningObjective)
  ))
_sym_db.RegisterMessage(HyperparameterTuningObjective)

HyperparameterTuningStrategy = _reflection.GeneratedProtocolMessageType('HyperparameterTuningStrategy', (_message.Message,), dict(
  DESCRIPTOR = _HYPERPARAMETERTUNINGSTRATEGY,
  __module__ = 'flyteidl.plugins.sagemaker.hyperparameter_tuning_job_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.plugins.sagemaker.HyperparameterTuningStrategy)
  ))
_sym_db.RegisterMessage(HyperparameterTuningStrategy)

TrainingJobEarlyStoppingType = _reflection.GeneratedProtocolMessageType('TrainingJobEarlyStoppingType', (_message.Message,), dict(
  DESCRIPTOR = _TRAININGJOBEARLYSTOPPINGTYPE,
  __module__ = 'flyteidl.plugins.sagemaker.hyperparameter_tuning_job_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.plugins.sagemaker.TrainingJobEarlyStoppingType)
  ))
_sym_db.RegisterMessage(TrainingJobEarlyStoppingType)

HyperparameterTuningJobConfig = _reflection.GeneratedProtocolMessageType('HyperparameterTuningJobConfig', (_message.Message,), dict(
  DESCRIPTOR = _HYPERPARAMETERTUNINGJOBCONFIG,
  __module__ = 'flyteidl.plugins.sagemaker.hyperparameter_tuning_job_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.plugins.sagemaker.HyperparameterTuningJobConfig)
  ))
_sym_db.RegisterMessage(HyperparameterTuningJobConfig)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: flyteidl/admin/common.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from flyteidl.core import execution_pb2 as flyteidl_dot_core_dot_execution__pb2
from flyteidl.core import identifier_pb2 as flyteidl_dot_core_dot_identifier__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='flyteidl/admin/common.proto',
  package='flyteidl.admin',
  syntax='proto3',
  serialized_options=_b('Z1github.com/lyft/flyteidl/gen/pb-go/flyteidl/admin'),
  serialized_pb=_b('\n\x1b\x66lyteidl/admin/common.proto\x12\x0e\x66lyteidl.admin\x1a\x1d\x66lyteidl/core/execution.proto\x1a\x1e\x66lyteidl/core/identifier.proto\"F\n\x15NamedEntityIdentifier\x12\x0f\n\x07project\x18\x01 \x01(\t\x12\x0e\n\x06\x64omain\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"[\n\x13NamedEntityMetadata\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12/\n\x05state\x18\x02 \x01(\x0e\x32 .flyteidl.admin.NamedEntityState\"\xab\x01\n\x0bNamedEntity\x12\x32\n\rresource_type\x18\x01 \x01(\x0e\x32\x1b.flyteidl.core.ResourceType\x12\x31\n\x02id\x18\x02 \x01(\x0b\x32%.flyteidl.admin.NamedEntityIdentifier\x12\x35\n\x08metadata\x18\x03 \x01(\x0b\x32#.flyteidl.admin.NamedEntityMetadata\"r\n\x04Sort\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x31\n\tdirection\x18\x02 \x01(\x0e\x32\x1e.flyteidl.admin.Sort.Direction\"*\n\tDirection\x12\x0e\n\nDESCENDING\x10\x00\x12\r\n\tASCENDING\x10\x01\"\x99\x01\n NamedEntityIdentifierListRequest\x12\x0f\n\x07project\x18\x01 \x01(\t\x12\x0e\n\x06\x64omain\x18\x02 \x01(\t\x12\r\n\x05limit\x18\x03 \x01(\r\x12\r\n\x05token\x18\x04 \x01(\t\x12%\n\x07sort_by\x18\x05 \x01(\x0b\x32\x14.flyteidl.admin.Sort\x12\x0f\n\x07\x66ilters\x18\x06 \x01(\t\"\xc3\x01\n\x16NamedEntityListRequest\x12\x32\n\rresource_type\x18\x01 \x01(\x0e\x32\x1b.flyteidl.core.ResourceType\x12\x0f\n\x07project\x18\x02 \x01(\t\x12\x0e\n\x06\x64omain\x18\x03 \x01(\t\x12\r\n\x05limit\x18\x04 \x01(\r\x12\r\n\x05token\x18\x05 \x01(\t\x12%\n\x07sort_by\x18\x06 \x01(\x0b\x32\x14.flyteidl.admin.Sort\x12\x0f\n\x07\x66ilters\x18\x07 \x01(\t\"c\n\x19NamedEntityIdentifierList\x12\x37\n\x08\x65ntities\x18\x01 \x03(\x0b\x32%.flyteidl.admin.NamedEntityIdentifier\x12\r\n\x05token\x18\x02 \x01(\t\"O\n\x0fNamedEntityList\x12-\n\x08\x65ntities\x18\x01 \x03(\x0b\x32\x1b.flyteidl.admin.NamedEntity\x12\r\n\x05token\x18\x02 \x01(\t\"~\n\x15NamedEntityGetRequest\x12\x32\n\rresource_type\x18\x01 \x01(\x0e\x32\x1b.flyteidl.core.ResourceType\x12\x31\n\x02id\x18\x02 \x01(\x0b\x32%.flyteidl.admin.NamedEntityIdentifier\"\xb8\x01\n\x18NamedEntityUpdateRequest\x12\x32\n\rresource_type\x18\x01 \x01(\x0e\x32\x1b.flyteidl.core.ResourceType\x12\x31\n\x02id\x18\x02 \x01(\x0b\x32%.flyteidl.admin.NamedEntityIdentifier\x12\x35\n\x08metadata\x18\x03 \x01(\x0b\x32#.flyteidl.admin.NamedEntityMetadata\"\x1b\n\x19NamedEntityUpdateResponse\"9\n\x10ObjectGetRequest\x12%\n\x02id\x18\x01 \x01(\x0b\x32\x19.flyteidl.core.Identifier\"\x9e\x01\n\x13ResourceListRequest\x12\x31\n\x02id\x18\x01 \x01(\x0b\x32%.flyteidl.admin.NamedEntityIdentifier\x12\r\n\x05limit\x18\x02 \x01(\r\x12\r\n\x05token\x18\x03 \x01(\t\x12\x0f\n\x07\x66ilters\x18\x04 \x01(\t\x12%\n\x07sort_by\x18\x05 \x01(\x0b\x32\x14.flyteidl.admin.Sort\"-\n\x11\x45mailNotification\x12\x18\n\x10recipients_email\x18\x01 \x03(\t\"1\n\x15PagerDutyNotification\x12\x18\n\x10recipients_email\x18\x01 \x03(\t\"-\n\x11SlackNotification\x12\x18\n\x10recipients_email\x18\x01 \x03(\t\"\xf3\x01\n\x0cNotification\x12\x36\n\x06phases\x18\x01 \x03(\x0e\x32&.flyteidl.core.WorkflowExecution.Phase\x12\x32\n\x05\x65mail\x18\x02 \x01(\x0b\x32!.flyteidl.admin.EmailNotificationH\x00\x12;\n\npager_duty\x18\x03 \x01(\x0b\x32%.flyteidl.admin.PagerDutyNotificationH\x00\x12\x32\n\x05slack\x18\x04 \x01(\x0b\x32!.flyteidl.admin.SlackNotificationH\x00\x42\x06\n\x04type\"%\n\x07UrlBlob\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\r\n\x05\x62ytes\x18\x02 \x01(\x03\"k\n\x06Labels\x12\x32\n\x06values\x18\x01 \x03(\x0b\x32\".flyteidl.admin.Labels.ValuesEntry\x1a-\n\x0bValuesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"u\n\x0b\x41nnotations\x12\x37\n\x06values\x18\x01 \x03(\x0b\x32\'.flyteidl.admin.Annotations.ValuesEntry\x1a-\n\x0bValuesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"X\n\x08\x41uthRole\x12\x1c\n\x12\x61ssumable_iam_role\x18\x01 \x01(\tH\x00\x12$\n\x1akubernetes_service_account\x18\x02 \x01(\tH\x00\x42\x08\n\x06method\"5\n\x13RawOutputDataConfig\x12\x1e\n\x16output_location_prefix\x18\x01 \x01(\t*\\\n\x10NamedEntityState\x12\x17\n\x13NAMED_ENTITY_ACTIVE\x10\x00\x12\x19\n\x15NAMED_ENTITY_ARCHIVED\x10\x01\x12\x14\n\x10SYSTEM_GENERATED\x10\x02\x42\x33Z1github.com/lyft/flyteidl/gen/pb-go/flyteidl/adminb\x06proto3')
  ,
  dependencies=[flyteidl_dot_core_dot_execution__pb2.DESCRIPTOR,flyteidl_dot_core_dot_identifier__pb2.DESCRIPTOR,])

_NAMEDENTITYSTATE = _descriptor.EnumDescriptor(
  name='NamedEntityState',
  full_name='flyteidl.admin.NamedEntityState',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NAMED_ENTITY_ACTIVE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NAMED_ENTITY_ARCHIVED', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SYSTEM_GENERATED', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2468,
  serialized_end=2560,
)
_sym_db.RegisterEnumDescriptor(_NAMEDENTITYSTATE)

NamedEntityState = enum_type_wrapper.EnumTypeWrapper(_NAMEDENTITYSTATE)
NAMED_ENTITY_ACTIVE = 0
NAMED_ENTITY_ARCHIVED = 1
SYSTEM_GENERATED = 2


_SORT_DIRECTION = _descriptor.EnumDescriptor(
  name='Direction',
  full_name='flyteidl.admin.Sort.Direction',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DESCENDING', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ASCENDING', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=521,
  serialized_end=563,
)
_sym_db.RegisterEnumDescriptor(_SORT_DIRECTION)


_NAMEDENTITYIDENTIFIER = _descriptor.Descriptor(
  name='NamedEntityIdentifier',
  full_name='flyteidl.admin.NamedEntityIdentifier',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='project', full_name='flyteidl.admin.NamedEntityIdentifier.project', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='domain', full_name='flyteidl.admin.NamedEntityIdentifier.domain', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='flyteidl.admin.NamedEntityIdentifier.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=110,
  serialized_end=180,
)


_NAMEDENTITYMETADATA = _descriptor.Descriptor(
  name='NamedEntityMetadata',
  full_name='flyteidl.admin.NamedEntityMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='description', full_name='flyteidl.admin.NamedEntityMetadata.description', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='flyteidl.admin.NamedEntityMetadata.state', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=182,
  serialized_end=273,
)


_NAMEDENTITY = _descriptor.Descriptor(
  name='NamedEntity',
  full_name='flyteidl.admin.NamedEntity',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_type', full_name='flyteidl.admin.NamedEntity.resource_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='flyteidl.admin.NamedEntity.id', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='flyteidl.admin.NamedEntity.metadata', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=276,
  serialized_end=447,
)


_SORT = _descriptor.Descriptor(
  name='Sort',
  full_name='flyteidl.admin.Sort',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='flyteidl.admin.Sort.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='direction', full_name='flyteidl.admin.Sort.direction', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SORT_DIRECTION,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=449,
  serialized_end=563,
)


_NAMEDENTITYIDENTIFIERLISTREQUEST = _descriptor.Descriptor(
  name='NamedEntityIdentifierListRequest',
  full_name='flyteidl.admin.NamedEntityIdentifierListRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='project', full_name='flyteidl.admin.NamedEntityIdentifierListRequest.project', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='domain', full_name='flyteidl.admin.NamedEntityIdentifierListRequest.domain', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='limit', full_name='flyteidl.admin.NamedEntityIdentifierListRequest.limit', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='token', full_name='flyteidl.admin.NamedEntityIdentifierListRequest.token', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sort_by', full_name='flyteidl.admin.NamedEntityIdentifierListRequest.sort_by', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='filters', full_name='flyteidl.admin.NamedEntityIdentifierListRequest.filters', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=566,
  serialized_end=719,
)


_NAMEDENTITYLISTREQUEST = _descriptor.Descriptor(
  name='NamedEntityListRequest',
  full_name='flyteidl.admin.NamedEntityListRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_type', full_name='flyteidl.admin.NamedEntityListRequest.resource_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='project', full_name='flyteidl.admin.NamedEntityListRequest.project', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='domain', full_name='flyteidl.admin.NamedEntityListRequest.domain', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='limit', full_name='flyteidl.admin.NamedEntityListRequest.limit', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='token', full_name='flyteidl.admin.NamedEntityListRequest.token', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sort_by', full_name='flyteidl.admin.NamedEntityListRequest.sort_by', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='filters', full_name='flyteidl.admin.NamedEntityListRequest.filters', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=722,
  serialized_end=917,
)


_NAMEDENTITYIDENTIFIERLIST = _descriptor.Descriptor(
  name='NamedEntityIdentifierList',
  full_name='flyteidl.admin.NamedEntityIdentifierList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='entities', full_name='flyteidl.admin.NamedEntityIdentifierList.entities', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='token', full_name='flyteidl.admin.NamedEntityIdentifierList.token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=919,
  serialized_end=1018,
)


_NAMEDENTITYLIST = _descriptor.Descriptor(
  name='NamedEntityList',
  full_name='flyteidl.admin.NamedEntityList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='entities', full_name='flyteidl.admin.NamedEntityList.entities', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='token', full_name='flyteidl.admin.NamedEntityList.token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1020,
  serialized_end=1099,
)


_NAMEDENTITYGETREQUEST = _descriptor.Descriptor(
  name='NamedEntityGetRequest',
  full_name='flyteidl.admin.NamedEntityGetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_type', full_name='flyteidl.admin.NamedEntityGetRequest.resource_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='flyteidl.admin.NamedEntityGetRequest.id', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1101,
  serialized_end=1227,
)


_NAMEDENTITYUPDATEREQUEST = _descriptor.Descriptor(
  name='NamedEntityUpdateRequest',
  full_name='flyteidl.admin.NamedEntityUpdateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_type', full_name='flyteidl.admin.NamedEntityUpdateRequest.resource_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='flyteidl.admin.NamedEntityUpdateRequest.id', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='flyteidl.admin.NamedEntityUpdateRequest.metadata', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1230,
  serialized_end=1414,
)


_NAMEDENTITYUPDATERESPONSE = _descriptor.Descriptor(
  name='NamedEntityUpdateResponse',
  full_name='flyteidl.admin.NamedEntityUpdateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1416,
  serialized_end=1443,
)


_OBJECTGETREQUEST = _descriptor.Descriptor(
  name='ObjectGetRequest',
  full_name='flyteidl.admin.ObjectGetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='flyteidl.admin.ObjectGetRequest.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1445,
  serialized_end=1502,
)


_RESOURCELISTREQUEST = _descriptor.Descriptor(
  name='ResourceListRequest',
  full_name='flyteidl.admin.ResourceListRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='flyteidl.admin.ResourceListRequest.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='limit', full_name='flyteidl.admin.ResourceListRequest.limit', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='token', full_name='flyteidl.admin.ResourceListRequest.token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='filters', full_name='flyteidl.admin.ResourceListRequest.filters', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sort_by', full_name='flyteidl.admin.ResourceListRequest.sort_by', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1505,
  serialized_end=1663,
)


_EMAILNOTIFICATION = _descriptor.Descriptor(
  name='EmailNotification',
  full_name='flyteidl.admin.EmailNotification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='recipients_email', full_name='flyteidl.admin.EmailNotification.recipients_email', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1665,
  serialized_end=1710,
)


_PAGERDUTYNOTIFICATION = _descriptor.Descriptor(
  name='PagerDutyNotification',
  full_name='flyteidl.admin.PagerDutyNotification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='recipients_email', full_name='flyteidl.admin.PagerDutyNotification.recipients_email', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1712,
  serialized_end=1761,
)


_SLACKNOTIFICATION = _descriptor.Descriptor(
  name='SlackNotification',
  full_name='flyteidl.admin.SlackNotification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='recipients_email', full_name='flyteidl.admin.SlackNotification.recipients_email', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1763,
  serialized_end=1808,
)


_NOTIFICATION = _descriptor.Descriptor(
  name='Notification',
  full_name='flyteidl.admin.Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='phases', full_name='flyteidl.admin.Notification.phases', index=0,
      number=1, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='email', full_name='flyteidl.admin.Notification.email', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pager_duty', full_name='flyteidl.admin.Notification.pager_duty', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='slack', full_name='flyteidl.admin.Notification.slack', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='type', full_name='flyteidl.admin.Notification.type',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=1811,
  serialized_end=2054,
)


_URLBLOB = _descriptor.Descriptor(
  name='UrlBlob',
  full_name='flyteidl.admin.UrlBlob',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='url', full_name='flyteidl.admin.UrlBlob.url', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bytes', full_name='flyteidl.admin.UrlBlob.bytes', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2056,
  serialized_end=2093,
)


_LABELS_VALUESENTRY = _descriptor.Descriptor(
  name='ValuesEntry',
  full_name='flyteidl.admin.Labels.ValuesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='flyteidl.admin.Labels.ValuesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='flyteidl.admin.Labels.ValuesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2157,
  serialized_end=2202,
)

_LABELS = _descriptor.Descriptor(
  name='Labels',
  full_name='flyteidl.admin.Labels',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='values', full_name='flyteidl.admin.Labels.values', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_LABELS_VALUESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2095,
  serialized_end=2202,
)


_ANNOTATIONS_VALUESENTRY = _descriptor.Descriptor(
  name='ValuesEntry',
  full_name='flyteidl.admin.Annotations.ValuesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='flyteidl.admin.Annotations.ValuesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='flyteidl.admin.Annotations.ValuesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2157,
  serialized_end=2202,
)

_ANNOTATIONS = _descriptor.Descriptor(
  name='Annotations',
  full_name='flyteidl.admin.Annotations',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='values', full_name='flyteidl.admin.Annotations.values', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_ANNOTATIONS_VALUESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2204,
  serialized_end=2321,
)


_AUTHROLE = _descriptor.Descriptor(
  name='AuthRole',
  full_name='flyteidl.admin.AuthRole',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='assumable_iam_role', full_name='flyteidl.admin.AuthRole.assumable_iam_role', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='kubernetes_service_account', full_name='flyteidl.admin.AuthRole.kubernetes_service_account', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='method', full_name='flyteidl.admin.AuthRole.method',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=2323,
  serialized_end=2411,
)


_RAWOUTPUTDATACONFIG = _descriptor.Descriptor(
  name='RawOutputDataConfig',
  full_name='flyteidl.admin.RawOutputDataConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='output_location_prefix', full_name='flyteidl.admin.RawOutputDataConfig.output_location_prefix', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2413,
  serialized_end=2466,
)

_NAMEDENTITYMETADATA.fields_by_name['state'].enum_type = _NAMEDENTITYSTATE
_NAMEDENTITY.fields_by_name['resource_type'].enum_type = flyteidl_dot_core_dot_identifier__pb2._RESOURCETYPE
_NAMEDENTITY.fields_by_name['id'].message_type = _NAMEDENTITYIDENTIFIER
_NAMEDENTITY.fields_by_name['metadata'].message_type = _NAMEDENTITYMETADATA
_SORT.fields_by_name['direction'].enum_type = _SORT_DIRECTION
_SORT_DIRECTION.containing_type = _SORT
_NAMEDENTITYIDENTIFIERLISTREQUEST.fields_by_name['sort_by'].message_type = _SORT
_NAMEDENTITYLISTREQUEST.fields_by_name['resource_type'].enum_type = flyteidl_dot_core_dot_identifier__pb2._RESOURCETYPE
_NAMEDENTITYLISTREQUEST.fields_by_name['sort_by'].message_type = _SORT
_NAMEDENTITYIDENTIFIERLIST.fields_by_name['entities'].message_type = _NAMEDENTITYIDENTIFIER
_NAMEDENTITYLIST.fields_by_name['entities'].message_type = _NAMEDENTITY
_NAMEDENTITYGETREQUEST.fields_by_name['resource_type'].enum_type = flyteidl_dot_core_dot_identifier__pb2._RESOURCETYPE
_NAMEDENTITYGETREQUEST.fields_by_name['id'].message_type = _NAMEDENTITYIDENTIFIER
_NAMEDENTITYUPDATEREQUEST.fields_by_name['resource_type'].enum_type = flyteidl_dot_core_dot_identifier__pb2._RESOURCETYPE
_NAMEDENTITYUPDATEREQUEST.fields_by_name['id'].message_type = _NAMEDENTITYIDENTIFIER
_NAMEDENTITYUPDATEREQUEST.fields_by_name['metadata'].message_type = _NAMEDENTITYMETADATA
_OBJECTGETREQUEST.fields_by_name['id'].message_type = flyteidl_dot_core_dot_identifier__pb2._IDENTIFIER
_RESOURCELISTREQUEST.fields_by_name['id'].message_type = _NAMEDENTITYIDENTIFIER
_RESOURCELISTREQUEST.fields_by_name['sort_by'].message_type = _SORT
_NOTIFICATION.fields_by_name['phases'].enum_type = flyteidl_dot_core_dot_execution__pb2._WORKFLOWEXECUTION_PHASE
_NOTIFICATION.fields_by_name['email'].message_type = _EMAILNOTIFICATION
_NOTIFICATION.fields_by_name['pager_duty'].message_type = _PAGERDUTYNOTIFICATION
_NOTIFICATION.fields_by_name['slack'].message_type = _SLACKNOTIFICATION
_NOTIFICATION.oneofs_by_name['type'].fields.append(
  _NOTIFICATION.fields_by_name['email'])
_NOTIFICATION.fields_by_name['email'].containing_oneof = _NOTIFICATION.oneofs_by_name['type']
_NOTIFICATION.oneofs_by_name['type'].fields.append(
  _NOTIFICATION.fields_by_name['pager_duty'])
_NOTIFICATION.fields_by_name['pager_duty'].containing_oneof = _NOTIFICATION.oneofs_by_name['type']
_NOTIFICATION.oneofs_by_name['type'].fields.append(
  _NOTIFICATION.fields_by_name['slack'])
_NOTIFICATION.fields_by_name['slack'].containing_oneof = _NOTIFICATION.oneofs_by_name['type']
_LABELS_VALUESENTRY.containing_type = _LABELS
_LABELS.fields_by_name['values'].message_type = _LABELS_VALUESENTRY
_ANNOTATIONS_VALUESENTRY.containing_type = _ANNOTATIONS
_ANNOTATIONS.fields_by_name['values'].message_type = _ANNOTATIONS_VALUESENTRY
_AUTHROLE.oneofs_by_name['method'].fields.append(
  _AUTHROLE.fields_by_name['assumable_iam_role'])
_AUTHROLE.fields_by_name['assumable_iam_role'].containing_oneof = _AUTHROLE.oneofs_by_name['method']
_AUTHROLE.oneofs_by_name['method'].fields.append(
  _AUTHROLE.fields_by_name['kubernetes_service_account'])
_AUTHROLE.fields_by_name['kubernetes_service_account'].containing_oneof = _AUTHROLE.oneofs_by_name['method']
DESCRIPTOR.message_types_by_name['NamedEntityIdentifier'] = _NAMEDENTITYIDENTIFIER
DESCRIPTOR.message_types_by_name['NamedEntityMetadata'] = _NAMEDENTITYMETADATA
DESCRIPTOR.message_types_by_name['NamedEntity'] = _NAMEDENTITY
DESCRIPTOR.message_types_by_name['Sort'] = _SORT
DESCRIPTOR.message_types_by_name['NamedEntityIdentifierListRequest'] = _NAMEDENTITYIDENTIFIERLISTREQUEST
DESCRIPTOR.message_types_by_name['NamedEntityListRequest'] = _NAMEDENTITYLISTREQUEST
DESCRIPTOR.message_types_by_name['NamedEntityIdentifierList'] = _NAMEDENTITYIDENTIFIERLIST
DESCRIPTOR.message_types_by_name['NamedEntityList'] = _NAMEDENTITYLIST
DESCRIPTOR.message_types_by_name['NamedEntityGetRequest'] = _NAMEDENTITYGETREQUEST
DESCRIPTOR.message_types_by_name['NamedEntityUpdateRequest'] = _NAMEDENTITYUPDATEREQUEST
DESCRIPTOR.message_types_by_name['NamedEntityUpdateResponse'] = _NAMEDENTITYUPDATERESPONSE
DESCRIPTOR.message_types_by_name['ObjectGetRequest'] = _OBJECTGETREQUEST
DESCRIPTOR.message_types_by_name['ResourceListRequest'] = _RESOURCELISTREQUEST
DESCRIPTOR.message_types_by_name['EmailNotification'] = _EMAILNOTIFICATION
DESCRIPTOR.message_types_by_name['PagerDutyNotification'] = _PAGERDUTYNOTIFICATION
DESCRIPTOR.message_types_by_name['SlackNotification'] = _SLACKNOTIFICATION
DESCRIPTOR.message_types_by_name['Notification'] = _NOTIFICATION
DESCRIPTOR.message_types_by_name['UrlBlob'] = _URLBLOB
DESCRIPTOR.message_types_by_name['Labels'] = _LABELS
DESCRIPTOR.message_types_by_name['Annotations'] = _ANNOTATIONS
DESCRIPTOR.message_types_by_name['AuthRole'] = _AUTHROLE
DESCRIPTOR.message_types_by_name['RawOutputDataConfig'] = _RAWOUTPUTDATACONFIG
DESCRIPTOR.enum_types_by_name['NamedEntityState'] = _NAMEDENTITYSTATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

NamedEntityIdentifier = _reflection.GeneratedProtocolMessageType('NamedEntityIdentifier', (_message.Message,), dict(
  DESCRIPTOR = _NAMEDENTITYIDENTIFIER,
  __module__ = 'flyteidl.admin.common_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.NamedEntityIdentifier)
  ))
_sym_db.RegisterMessage(NamedEntityIdentifier)

NamedEntityMetadata = _reflection.GeneratedProtocolMessageType('NamedEntityMetadata', (_message.Message,), dict(
  DESCRIPTOR = _NAMEDENTITYMETADATA,
  __module__ = 'flyteidl.admin.common_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.NamedEntityMetadata)
  ))
_sym_db.RegisterMessage(NamedEntityMetadata)

NamedEntity = _reflection.GeneratedProtocolMessageType('NamedEntity', (_message.Message,), dict(
  DESCRIPTOR = _NAMEDENTITY,
  __module__ = 'flyteidl.admin.common_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.NamedEntity)
  ))
_sym_db.RegisterMessage(NamedEntity)

Sort = _reflection.GeneratedProtocolMessageType('Sort', (_message.Message,), dict(
  DESCRIPTOR = _SORT,
  __module__ = 'flyteidl.admin.common_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.Sort)
  ))
_sym_db.RegisterMessage(Sort)

NamedEntityIdentifierListRequest = _reflection.GeneratedProtocolMessageType('NamedEntityIdentifierListRequest', (_message.Message,), dict(
  DESCRIPTOR = _NAMEDENTITYIDENTIFIERLISTREQUEST,
  __module__ = 'flyteidl.admin.common_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.NamedEntityIdentifierListRequest)
  ))
_sym_db.RegisterMessage(NamedEntityIdentifierListRequest)

NamedEntityListRequest = _reflection.GeneratedProtocolMessageType('NamedEntityListRequest', (_message.Message,), dict(
  DESCRIPTOR = _NAMEDENTITYLISTREQUEST,
  __module__ = 'flyteidl.admin.common_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.NamedEntityListRequest)
  ))
_sym_db.RegisterMessage(NamedEntityListRequest)

NamedEntityIdentifierList = _reflection.GeneratedProtocolMessageType('NamedEntityIdentifierList', (_message.Message,), dict(
  DESCRIPTOR = _NAMEDENTITYIDENTIFIERLIST,
  __module__ = 'flyteidl.admin.common_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.NamedEntityIdentifierList)
  ))
_sym_db.RegisterMessage(NamedEntityIdentifierList)

NamedEntityList = _reflection.GeneratedProtocolMessageType('NamedEntityList', (_message.Message,), dict(
  DESCRIPTOR = _NAMEDENTITYLIST,
  __module__ = 'flyteidl.admin.common_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.NamedEntityList)
  ))
_sym_db.RegisterMessage(NamedEntityList)

NamedEntityGetRequest = _reflection.GeneratedProtocolMessageType('NamedEntityGetRequest', (_message.Message,), dict(
  DESCRIPTOR = _NAMEDENTITYGETREQUEST,
  __module__ = 'flyteidl.admin.common_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.NamedEntityGetRequest)
  ))
_sym_db.RegisterMessage(NamedEntityGetRequest)

NamedEntityUpdateRequest = _reflection.GeneratedProtocolMessageType('NamedEntityUpdateRequest', (_message.Message,), dict(
  DESCRIPTOR = _NAMEDENTITYUPDATEREQUEST,
  __module__ = 'flyteidl.admin.common_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.NamedEntityUpdateRequest)
  ))
_sym_db.RegisterMessage(NamedEntityUpdateRequest)

NamedEntityUpdateResponse = _reflection.GeneratedProtocolMessageType('NamedEntityUpdateResponse', (_message.Message,), dict(
  DESCRIPTOR = _NAMEDENTITYUPDATERESPONSE,
  __module__ = 'flyteidl.admin.common_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.NamedEntityUpdateResponse)
  ))
_sym_db.RegisterMessage(NamedEntityUpdateResponse)

ObjectGetRequest = _reflection.GeneratedProtocolMessageType('ObjectGetRequest', (_message.Message,), dict(
  DESCRIPTOR = _OBJECTGETREQUEST,
  __module__ = 'flyteidl.admin.common_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.ObjectGetRequest)
  ))
_sym_db.RegisterMessage(ObjectGetRequest)

ResourceListRequest = _reflection.GeneratedProtocolMessageType('ResourceListRequest', (_message.Message,), dict(
  DESCRIPTOR = _RESOURCELISTREQUEST,
  __module__ = 'flyteidl.admin.common_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.ResourceListRequest)
  ))
_sym_db.RegisterMessage(ResourceListRequest)

EmailNotification = _reflection.GeneratedProtocolMessageType('EmailNotification', (_message.Message,), dict(
  DESCRIPTOR = _EMAILNOTIFICATION,
  __module__ = 'flyteidl.admin.common_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.EmailNotification)
  ))
_sym_db.RegisterMessage(EmailNotification)

PagerDutyNotification = _reflection.GeneratedProtocolMessageType('PagerDutyNotification', (_message.Message,), dict(
  DESCRIPTOR = _PAGERDUTYNOTIFICATION,
  __module__ = 'flyteidl.admin.common_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.PagerDutyNotification)
  ))
_sym_db.RegisterMessage(PagerDutyNotification)

SlackNotification = _reflection.GeneratedProtocolMessageType('SlackNotification', (_message.Message,), dict(
  DESCRIPTOR = _SLACKNOTIFICATION,
  __module__ = 'flyteidl.admin.common_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.SlackNotification)
  ))
_sym_db.RegisterMessage(SlackNotification)

Notification = _reflection.GeneratedProtocolMessageType('Notification', (_message.Message,), dict(
  DESCRIPTOR = _NOTIFICATION,
  __module__ = 'flyteidl.admin.common_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.Notification)
  ))
_sym_db.RegisterMessage(Notification)

UrlBlob = _reflection.GeneratedProtocolMessageType('UrlBlob', (_message.Message,), dict(
  DESCRIPTOR = _URLBLOB,
  __module__ = 'flyteidl.admin.common_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.UrlBlob)
  ))
_sym_db.RegisterMessage(UrlBlob)

Labels = _reflection.GeneratedProtocolMessageType('Labels', (_message.Message,), dict(

  ValuesEntry = _reflection.GeneratedProtocolMessageType('ValuesEntry', (_message.Message,), dict(
    DESCRIPTOR = _LABELS_VALUESENTRY,
    __module__ = 'flyteidl.admin.common_pb2'
    # @@protoc_insertion_point(class_scope:flyteidl.admin.Labels.ValuesEntry)
    ))
  ,
  DESCRIPTOR = _LABELS,
  __module__ = 'flyteidl.admin.common_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.Labels)
  ))
_sym_db.RegisterMessage(Labels)
_sym_db.RegisterMessage(Labels.ValuesEntry)

Annotations = _reflection.GeneratedProtocolMessageType('Annotations', (_message.Message,), dict(

  ValuesEntry = _reflection.GeneratedProtocolMessageType('ValuesEntry', (_message.Message,), dict(
    DESCRIPTOR = _ANNOTATIONS_VALUESENTRY,
    __module__ = 'flyteidl.admin.common_pb2'
    # @@protoc_insertion_point(class_scope:flyteidl.admin.Annotations.ValuesEntry)
    ))
  ,
  DESCRIPTOR = _ANNOTATIONS,
  __module__ = 'flyteidl.admin.common_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.Annotations)
  ))
_sym_db.RegisterMessage(Annotations)
_sym_db.RegisterMessage(Annotations.ValuesEntry)

AuthRole = _reflection.GeneratedProtocolMessageType('AuthRole', (_message.Message,), dict(
  DESCRIPTOR = _AUTHROLE,
  __module__ = 'flyteidl.admin.common_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.AuthRole)
  ))
_sym_db.RegisterMessage(AuthRole)

RawOutputDataConfig = _reflection.GeneratedProtocolMessageType('RawOutputDataConfig', (_message.Message,), dict(
  DESCRIPTOR = _RAWOUTPUTDATACONFIG,
  __module__ = 'flyteidl.admin.common_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.RawOutputDataConfig)
  ))
_sym_db.RegisterMessage(RawOutputDataConfig)


DESCRIPTOR._options = None
_LABELS_VALUESENTRY._options = None
_ANNOTATIONS_VALUESENTRY._options = None
# @@protoc_insertion_point(module_scope)
